@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2014 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 import hashlib
 
 import os
@@ -22,13 +23,15 @@ import re
 import sys
 from calculate.lib.utils.colortext.palette import TextState
 from calculate.lib.utils.tools import ignore
-from calculate.lib.utils.portage import EmergePackage, PackageList, EmergeUpdateInfo, \
-    EmergeRemoveInfo, Git, GitError
+from calculate.lib.utils.portage import (EmergePackage, PackageList,
+                                         EmergeUpdateInfo,
+                                         EmergeRemoveInfo, Git, GitError)
 
 Colors = TextState.Colors
 import pexpect
-from calculate.lib.utils.files import getProgPath, readLinesFile, listDirectory, \
-    writeFile, readFile
+from calculate.lib.utils.files import (getProgPath, readLinesFile,
+                                       listDirectory,
+                                       writeFile, readFile)
 from calculate.lib.utils.colortext.output import XmlOutput
 from calculate.lib.utils.colortext.converter import (ConsoleCodes256Converter,
                                                      XmlConverter)
@@ -39,6 +42,7 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 setLocalTranslate('cl_update3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
+linux_term_env = {'TERM': 'linux'}
 
 class EmergeError(Exception):
     """
@@ -50,8 +54,6 @@ class EmergeNeedRootError(EmergeError):
     pass
 
 
-env_terminal_linux = {'TERM':'linux'}
-
 class CommandExecutor(object):
     """
     Запуск программы для объекта Emerge
@@ -61,17 +63,21 @@ class CommandExecutor(object):
     def __init__(self, cmd, params, env=None, cwd=None, logfile=None):
         self.cwd = cwd
         self.env = env or dict(os.environ)
-        self.env.update({'EINFO_QUIET':'NO'})
-        self.env.update(env_terminal_linux)
+        self.env.update({'EINFO_QUIET': 'NO'})
+        self.env.update(linux_term_env)
         self.cmd = cmd
         self.params = params
         self.child = None
         if logfile:
             self.logfile = logfile
 
+    def get_command(self):
+        return [self.cmd] + list(self.params)
+
     def execute(self):
         if self.child is None:
-            self.child = pexpect.spawn(self.cmd,
+            command_data = self.get_command()
+            self.child = pexpect.spawn(command_data[0], command_data[1:],
                                        logfile=open(self.logfile, 'w'),
                                        env=self.env, cwd=self.cwd, timeout=None)
         return self.child
@@ -102,50 +108,95 @@ class EmergeCommand(CommandExecutor):
     """
     # параметры по умолчанию
     default_params = ["-av", "--color=y", "--nospinner"]
-    cmd = getProgPath("/usr/bin/emerge")
+    emerge_cmd = getProgPath("/usr/bin/emerge")
 
     def __init__(self, packages, extra_params=None, env=None, cwd=None,
-                 logfile=None, emerge_default_opts=None):
+                 logfile=None, emerge_default_opts=None, use=""):
         extra_params = extra_params or []
-        self.child = None
-        self.packages = packages
-        self.params = self.default_params + extra_params
-        if emerge_default_opts is None:
-            default_env = {'CLEAN_DELAY': '0'}
-        else:
-            default_env = {
-                'CLEAN_DELAY': '0',
-                'EMERGE_DEFAULT_OPTS': re.sub(r'(?:^|\s)(--columns)(?=\s|$)','',
-                    emerge_default_opts)
-            }
-        default_env.update(os.environ)
-        self.env = env or default_env
-        self.env.update(env_terminal_linux)
-        self.cwd = cwd
-        if logfile:
-            self.logfile = logfile
+        if env is None:
+            if emerge_default_opts is None:
+                env = {'CLEAN_DELAY': '0'}
+            else:
+                env = {
+                    'CLEAN_DELAY': '0',
+                    'EMERGE_DEFAULT_OPTS': re.sub(
+                        r'(?:^|\s)(--columns)(?=\s|$)', '',
+                        emerge_default_opts)
+                }
+                if use:
+                    env["USE"] = use
+            env.update(os.environ)
 
-    def execute(self):
-        if self.child is None:
-            self.child = pexpect.spawn(self.cmd, self.params + self.packages,
-                                       logfile=open(self.logfile, 'w'),
-                                       env=self.env, cwd=self.cwd, timeout=None)
-        return self.child
+        params = self.default_params + extra_params + packages
+        super(EmergeCommand, self).__init__(self.emerge_cmd, params=params,
+                                            env=env, cwd=cwd, logfile=logfile)
 
 
-class EmergeInformationBlock(object):
-    _color_block = "(?:\033\[[^m]+?m)?"
-    _new_line = "\r*\n"
+def Chroot(chroot_path, obj):
+    """
+    Преобразовать команду (экземпляр объекта) в chroot
+    :param obj: экземпляр команды
+    :param chroot_path: путь для chroot
+    :return:
+    """
+    old_get_command = obj.get_command
+
+    def get_command():
+        chrootCmd = '/usr/bin/chroot'
+        bashCmd = '/bin/bash'
+        bash_command = (
+            "env-update &>/dev/null;"
+            "source /etc/profile &>/dev/null;"
+            "{cmd}".format(cmd=" ".join(old_get_command())))
+        return [chrootCmd, chroot_path, bashCmd, "-c", bash_command]
+    obj.get_command = get_command
+    return obj
+
+
+def Linux32(obj):
+    """
+    Преобразовать команду (экземпляр объекта) в вызов под linux32
+    :param obj: экземпляр команды
+    :return:
+    """
+    old_get_command = obj.get_command
+
+    def get_command():
+        return ["/usr/bin/linux32"] + old_get_command()
+    obj.get_command = get_command
+    return obj
+
+
+class InfoBlockInterface(object):
+    """
+    Интерфейс для информационного блока
+    """
+    action = None
     token = None
+    result = None
+    text_converter = ConsoleCodes256Converter(XmlOutput())
+
+    def get_block(self, child):
+        pass
+
+    def add_element(self, element):
+        """
+        :type element: InfoBlockInterface
+        """
+        pass
+
+
+class EmergeInformationBlock(InfoBlockInterface):
+    _color_block = "(?:\033\[[^m]+?m)?"
+    _new_line = "(?:\r*\n)"
     end_token = ["\n"]
     re_block = None
-    action = None
     re_match_type = type(re.match("", ""))
     re_type = type(re.compile(""))
 
     def __init__(self, parent):
         """
-        :type parent: EmergeParser
+        :type parent: InfoBlockInterface
         """
         self.result = None
         self.text_converter = parent.text_converter
@@ -154,6 +205,9 @@ class EmergeInformationBlock(object):
         self.children = []
 
     def add_element(self, element):
+        """
+        :type element: InfoBlockInterface
+        """
         self.children.append(element)
 
     def __str__(self):
@@ -238,7 +292,7 @@ class UninstallPackagesBlock(EmergeInformationBlock):
     _new_line = EmergeInformationBlock._new_line
     _color_block = EmergeInformationBlock._color_block
     token = ["Calculating removal order",
-             "These are the packages that would be unmerged",]
+             "These are the packages that would be unmerged"]
     end_token = re.compile("All selected packages:.*\n")
     re_block = re.compile(
         r"(?:{token}).*?{nl}(.*){nl}All selected packages: (.*?){nl}".
@@ -257,7 +311,29 @@ class UninstallPackagesBlock(EmergeInformationBlock):
         self.list = PackageList(map(EmergePackage, list_block))
 
 
-class FinishEmergeGroup(EmergeInformationBlock):
+class GroupEmergeInformationBlock(EmergeInformationBlock):
+    """
+    Группа блоков
+    """
+    def get_block(self, child):
+        self.children_get_block(child)
+        self.result = True
+
+    def children_get_block(self, child):
+        for block in self.children:
+            block.get_block(child)
+
+    def children_action(self, child):
+        for block in (x for x in self.children if x.result and x.action):
+            if block.action(child) is False:
+                return False
+
+    def action(self, child):
+        self.children_action(child)
+        return False
+
+
+class FinishEmergeGroup(GroupEmergeInformationBlock):
     """
     Блок завершения команды
     """
@@ -280,19 +356,6 @@ class FinishEmergeGroup(EmergeInformationBlock):
         else:
             self.result = True
 
-    def children_get_block(self, child):
-        for block in self.children:
-            block.get_block(child)
-
-    def children_action(self, child):
-        for block in (x for x in self.children if x.result and x.action):
-            if block.action(child) is False:
-                break
-
-    def action(self, child):
-        self.children_action(child)
-        return False
-
 
 class PrepareErrorBlock(EmergeInformationBlock):
     """
@@ -341,21 +404,88 @@ class DownloadSizeBlock(EmergeInformationBlock):
         else:
             return "0 kB"
 
+class SkippedPackagesBlock(EmergeInformationBlock):
+    """
+    Размер скачиваемых обновлений
+    """
+    token = "The following update has been skipped"
+    end_token = ["For more information, see the MASKED"]
+
+    re_block = re.compile(
+        r"(The following update has.*?)(?=For more information)", re.S)
+
+    def __str__(self):
+        if self.result:
+            return self.result
+        else:
+            return ""
+
+class QuestionGroup(GroupEmergeInformationBlock):
+    """
+    Группа блоков разбора вопросов от emerge
+    """
+    token = "Would you like"
+    end_token = ["]", "\n"]
+    _color_block = EmergeInformationBlock._color_block
+    re_block = re.compile(
+        "(Would you.*)\[{c}Yes{c}/{c}No{c}".format(c=_color_block))
+
+    def get_block(self, child):
+        try:
+            before = child.before
+            token = child.match
+            if type(self.end_token) == self.re_type:
+                child.expect(self.end_token)
+                match = child.match.group()
+            else:
+                child.expect_exact(self.end_token)
+                match = child.match
+            data = token + child.before + match
+            child.before = before
+            for block in self.children:
+                child.match = re.search(block.token, data)
+                block.get_block(child)
+                if block.result:
+                    break
+        except pexpect.EOF:
+            child.buffer = "".join(
+                [x for x in (child.before, child.after, child.buffer)
+                 if type(x) == str])
+
+class QuestionChangeConfigBlock(GroupEmergeInformationBlock):
+    """
+    Вопрос об изменении конфигурационных файлов
+    """
+    token = "Would you like to add these changes to your config files"
+
+    def get_block(self, child):
+        if child.match:
+            self.result = self.token
+            self.children_get_block(child)
+
+    def action(self, child):
+        if self.result:
+            child.send("no\n")
+            if child.isalive():
+                child.wait()
+            self.children_action(child)
+
 
 class QuestionBlock(EmergeInformationBlock):
     """
     Блок вопроса
     """
     default_answer = "yes"
-    _color_block = EmergeInformationBlock._color_block
-    token = "Would you like"
-    end_token = ["]", "\n"]
-    re_block = re.compile(
-        "(Would you.*)\[{c}Yes{c}/{c}No{c}".format(c=_color_block))
+    token = "Would you"
+
+    def get_block(self, child):
+        if child.match:
+            self.result = self.token
 
     def action(self, child):
         if self.result:
             child.send("%s\n" % self.default_answer)
+            return False
 
 
 class NeedRootBlock(EmergeInformationBlock):
@@ -445,6 +575,7 @@ class FetchingTarball(NotifierInformationBlock):
     def notify(self, observer, groups):
         observer(groups[0])
 
+
 class InstallingPackage(NotifierInformationBlock):
     """
     Запуск устанавливаемого пакета
@@ -521,23 +652,27 @@ class RevdepPercentBlock(NotifierInformationBlock):
         except pexpect.EOF:
             self.result = ""
 
-class EmergeParser(object):
+class EmergeParser(InfoBlockInterface):
     """
     Парсер вывода emerge
     """
 
     def __init__(self, command, run=False):
-        self.text_converter = ConsoleCodes256Converter(XmlOutput())
         self.command = command
         self.elements = {}
 
         self.install_packages = InstallPackagesBlock(self)
         self.uninstall_packages = UninstallPackagesBlock(self)
-        self.question = QuestionBlock(self)
+        self.question_group = QuestionGroup(self)
+        self.change_config_question = QuestionChangeConfigBlock(
+            self.question_group)
+        self.question = QuestionBlock(self.question_group)
         self.finish_block = FinishEmergeGroup(self)
         self.need_root = NeedRootBlock(self)
         self.prepare_error = PrepareErrorBlock(self.finish_block)
+        self.change_config_question.add_element(self.prepare_error)
         self.download_size = DownloadSizeBlock(self)
+        self.skipped_packages = SkippedPackagesBlock(self)
         self.emerging_error = EmergeingErrorBlock(self)
 
         self.installing = InstallingPackage(self)
@@ -558,6 +693,9 @@ class EmergeParser(object):
         self.fetching.action = lambda child: None
 
     def add_element(self, element):
+        """
+        :type element: InfoBlockInterface
+        """
         if element.token:
             if type(element.token) == list:
                 for token in element.token:
@@ -613,6 +751,7 @@ class Md5Checkvalue(MtimeCheckvalue):
     def value_func(self, fn):
         return hashlib.md5(readFile(fn)).hexdigest()
 
+
 class GitCheckvalue(object):
     def __init__(self, rpath):
         self.rpath = rpath
@@ -631,10 +770,10 @@ class EmergeCache(object):
     cache_file = '/var/lib/calculate/calculate-update/world.cache'
     # список файлов проверяемый по mtime на изменения
     check_list = [MtimeCheckvalue('/etc/make.conf',
-                  '/etc/portage',
-                  '/etc/make.profile'),
+                                  '/etc/portage',
+                                  '/etc/make.profile'),
                   Md5Checkvalue('/var/lib/portage/world',
-                  '/var/lib/portage/world_sets')]
+                                '/var/lib/portage/world_sets')]
     logger = log("emerge-cache",
                  filename="/var/log/calculate/emerge-cache.log",
                  formatter="%(asctime)s - %(levelname)s - %(message)s")
@@ -652,16 +791,16 @@ class EmergeCache(object):
                 f.write("{fn}={val}\n".format(fn=fn, val=val))
             f.write('\n')
             for pkg in package_list:
-                f.write("%s\n"% str(pkg))
-        self.logger.info("Setting cache (%d packages)"%len(package_list))
+                f.write("%s\n" % str(pkg))
+        self.logger.info("Setting cache (%d packages)" % len(package_list))
 
     def drop_cache(self, reason=None):
         if path.exists(self.cache_file):
             with ignore(OSError):
                 os.unlink(self.cache_file)
-            self.logger.info("Droping cache. Reason: %s"%reason)
+            self.logger.info("Droping cache. Reason: %s" % reason)
         else:
-            self.logger.info("Droping empty cache. Reason: %s"%reason)
+            self.logger.info("Droping empty cache. Reason: %s" % reason)
 
     def get_cached_package_list(self):
         self.read_cache()
@@ -681,10 +820,10 @@ class EmergeCache(object):
             return True
         else:
             reason = "Unknown"
-            for k,v in self.get_control_values().items():
+            for k, v in self.get_control_values().items():
                 if k in self.files_control_values:
                     if v != self.files_control_values[k]:
-                        reason = "%s was modified"%k
+                        reason = "%s was modified" % k
                 else:
                     reason = "Checksum of file %s is not exist" % k
             self.logger.info("Failed to get cache. Reason: %s" % reason)
@@ -694,7 +833,7 @@ class EmergeCache(object):
         self.files_control_values = {}
         cache_file_lines = readLinesFile(self.cache_file)
         for line in cache_file_lines:
-            if not "=" in line:
+            if "=" not in line:
                 break
             k, v = line.split('=')
             self.files_control_values[k] = v.strip()
@@ -703,6 +842,7 @@ class EmergeCache(object):
     def get_control_values(self):
         def generate():
             for obj in self.check_list:
-                for checkvalue in obj.checkvalues():
-                    yield checkvalue
+                for check_value in obj.checkvalues():
+                    yield check_value
+
         return dict(generate())
