@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,18 +18,35 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
-from calculate.lib.utils.colortext import get_color_print, Colors
 from calculate.lib.utils.files import FilesError
 from calculate.update.update import UpdateError
 from calculate.update.emerge_parser import EmergeError
-from calculate.lib.utils.portage import GitError, Eix, EmergeLog, \
-    EmergeLogNamedTask, PackageList
-from ..update_tasks import EmergeMark
+from calculate.lib.utils.portage import (GitError, EmergeLog,
+                                         EmergeLogNamedTask, PackageList)
+from calculate.update.update_tasks import EmergeMark
 
+_ = lambda x: x
 setLocalTranslate('cl_update3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 
+class UpdateConditions(object):
+    @staticmethod
+    def was_installed(pkg, task_name):
+        def func():
+            task = EmergeLog(EmergeLogNamedTask(task_name))
+            return bool(PackageList(task.list)[pkg])
+        return func
+
+    @staticmethod
+    def need_depclean(pkg, task_name):
+        def func(Get):
+            task = EmergeLog(EmergeLogNamedTask(task_name))
+            return (bool(PackageList(task.list)[pkg])
+                    or Get('cl_update_outdated_kernel_set') == 'on')
+        return func
+
+
 class ClUpdateAction(Action):
     """
     Действие обновление конфигурационных файлов
@@ -43,28 +60,6 @@ class ClUpdateAction(Action):
     failedMessage = None
     interruptMessage = __("Update manually interrupted")
 
-    def was_installed(pkg, task_name):
-        def func():
-            task = EmergeLog(EmergeLogNamedTask(task_name))
-            return bool(PackageList(task.list)[pkg])
-        return func
-
-    def need_depclean(pkg, task_name):
-        def func(Get):
-            task = EmergeLog(EmergeLogNamedTask(task_name))
-            return (bool(PackageList(task.list)[pkg])
-                    or Get('cl_update_outdated_kernel_set') == 'on')
-        return func
-
-    def need_upgrade(pkg):
-        # TODO: возможно функция не работает
-        def func():
-            return bool(Eix(pkg, Eix.Option.Upgrade).get_packages())
-        return func
-
-    def pkg_color(text):
-        return text
-
     emerge_tasks = [
         {'name': 'premerge_group',
          'group': __("Checking for updates"),
@@ -74,24 +69,24 @@ class ClUpdateAction(Action):
              'method': 'Update.premerge("-uDN","--with-bdeps=y","@world")',
              'condition': lambda Get:Get('cl_update_sync_only_set') == 'off'
             }],
-        },
+         },
         {'name': 'premerge:update',
          'condition': lambda Get:Get('cl_update_pretend_set') == 'off',
          'depend': Tasks.result("premerge", eq='yes')
-        },
+         },
         {'name': 'update_other',
          'condition': lambda Get: ( Get('cl_update_pretend_set') == 'off' and
                                     Get('cl_update_sync_only_set') == 'off')
-        },
+         },
         {'name': 'update:update_world',
          'group': __("Updating packages"),
          'tasks': [
              {'name': 'update:update_world',
               'message': __("Calculating dependencies"),
               'method': 'Update.emerge("","-uDN","--with-bdeps=y","@world")',
-             }
+              }
          ]
-        },
+         },
         {'name': 'update:update_python',
          'group': __("Updating Python"),
          'tasks': [
@@ -99,11 +94,11 @@ class ClUpdateAction(Action):
               'message': __('Find & rebuild packages broken due '
                             'to a Python upgrade'),
               'method': 'Update.emergelike("python-updater")',
-              'condition': was_installed('dev-lang/python$',
-                                         EmergeMark.PythonUpdater),
+              'condition': UpdateConditions.was_installed(
+                  'dev-lang/python$', EmergeMark.PythonUpdater),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.PythonUpdater
-             },
+              },
          ]
         },
         {'name': 'update:update_perl',
@@ -113,8 +108,8 @@ class ClUpdateAction(Action):
               'message': __('Find & rebuild packages and Perl header files '
                             'broken due to a perl upgrade'),
               'method': 'Update.emergelike("perl-cleaner", "all")',
-              'condition': was_installed('dev-lang/perl$',
-                                         EmergeMark.PerlCleaner),
+              'condition': UpdateConditions.was_installed(
+                  'dev-lang/perl$', EmergeMark.PerlCleaner),
               'decoration': 'Update.update_task("%s")' % EmergeMark.PerlCleaner
              },
          ]
@@ -125,7 +120,8 @@ class ClUpdateAction(Action):
              {'name': 'update_other:update_depclean',
               'message': __("Calculating dependencies"),
               'method': 'Update.depclean()',
-              'condition': need_depclean('.*', EmergeMark.Depclean),
+              'condition': UpdateConditions.need_depclean(
+                  '.*', EmergeMark.Depclean),
               'decoration': 'Update.update_task("%s")' % EmergeMark.Depclean
              },
          ]
@@ -136,38 +132,40 @@ class ClUpdateAction(Action):
              {'name': 'update_other:module_rebuild',
               'message': __('Updating Kernel modules'),
               'method': 'Update.emerge("","@module-rebuild")',
-              'condition': was_installed('sys-kernel/.*source',
-                                         EmergeMark.KernelModules),
+              'condition': UpdateConditions.was_installed(
+                  'sys-kernel/.*source', EmergeMark.KernelModules),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.KernelModules
              },
              {'name': 'update_other:x11_module_rebuild',
               'message': __('Updating X.Org server modules'),
               'method': 'Update.emerge("","@x11-module-rebuild")',
-              'condition': was_installed('x11-base/xorg-server',
-                                         EmergeMark.XorgModules),
+              'condition': UpdateConditions.was_installed(
+                  'x11-base/xorg-server', EmergeMark.XorgModules),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.XorgModules
              },
              {'name': 'update_other:preserved_rebuild',
               'message': __('Updating preserved libraries'),
               'method': 'Update.emerge("","@preserved-rebuild")',
-              'condition': was_installed('.*', EmergeMark.PreservedLibs),
+              'condition': UpdateConditions.was_installed(
+                  '.*', EmergeMark.PreservedLibs),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.PreservedLibs
              },
              {'name': 'update_other:revdev_rebuild',
               'message': __('Checking reverse dependencies'),
               'method': 'Update.revdep_rebuild("revdep-rebuild")',
-              'condition': lambda Get:(Get('cl_update_skip_rb_set') == 'off'
-                    and ClUpdateAction.was_installed('.*',
-                            EmergeMark.RevdepRebuild)()),
+              'condition': lambda Get: (Get(
+                  'cl_update_skip_rb_set') == 'off' and
+                  UpdateConditions.was_installed(
+                      '.*', EmergeMark.RevdepRebuild)()),
               'decoration': 'Update.update_task("%s")' %
                             EmergeMark.RevdepRebuild
              },
              {'name': 'update_other:dispatch_conf_end',
               'message': __("Updating configuration files"),
-              'method':'Update.dispatchConf()',
+              'method': 'Update.dispatchConf()',
               'condition': lambda Get: (Get('cl_dispatch_conf') != 'skip' and
                                         Get('cl_update_pretend_set') == 'off')
              },
@@ -305,18 +303,16 @@ class ClUpdateAction(Action):
                      Tasks.success_all("check_schedule")))},
         {'name': 'failed',
          'depend': Tasks.failed_all("check_schedule")
-        },
+         },
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'success_rev',
          'message': __("System update finished!"),
          'condition': lambda Get: (Get('cl_update_rev_set') == 'on' and
                                     Get('cl_update_pretend_set') == 'off')
-        },
+         },
         # сообщение удачного завершения при пересоздании world
         {'name': 'success_world',
          'message': __("World rebuild finished!"),
          'condition': lambda Get: Get('cl_rebuild_world_set') == 'on'
-        },
+         },
     ]
-    
-    was_installed = staticmethod(was_installed)
