@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2013-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -19,18 +19,17 @@ import sys
 import re
 from os import path
 from calculate.lib.datavars import (Variable, VariableError,
-    ReadonlyVariable, ReadonlyTableVariable, TableVariable, FieldValue,
-    SimpleDataVars, DataVarsError)
-from calculate.lib.utils.files import readFile, \
-    listDirectory, process, pathJoin
-from calculate.lib.utils.git import Git
+                                    ReadonlyVariable, ReadonlyTableVariable,
+                                    TableVariable, FieldValue,
+                                    SimpleDataVars, DataVarsError)
+from calculate.lib.utils.files import readFile, listDirectory, process, pathJoin
 
 from calculate.lib.configparser import ConfigParser
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.utils.text import simplify_profiles
 from calculate.lib.utils.portage import Git, GitError, Layman
-from ..profile import RepositoryStorageSet, DEFAULT_BRANCH, \
-    LocalStorage, ProfileRepository, CacheStorage
+from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
+                       LocalStorage, ProfileRepository, CacheStorage)
 
 from calculate.lib.variables import linux as lib_linux
 from calculate.lib.variables import env
@@ -38,7 +37,7 @@ from calculate.update.update_info import UpdateInfo
 import urllib2
 import time
 
-_ = lambda x:x
+_ = lambda x: x
 
 setLocalTranslate('cl_update3', sys.modules[__name__])
 
@@ -552,7 +551,7 @@ class VariableClUpdateOtherRepData(ReadonlyTableVariable):
             if rname in layman_overlays and rname not in repNames:
                 yield (rname, rpath)
 
-    def get(self):
+    def get(self, hr=False):
         return list(self.generator())
 
 class VariableClUpdateOtherRepName(FieldValue,ReadonlyVariable):
