@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -16,17 +16,18 @@
 
 import sys
 
-from calculate.lib.datavars import VariableError,DataVarsError,DataVars
+from calculate.lib.datavars import VariableError,DataVarsError
 
 from calculate.core.server.func import WsdlBase
 from calculate.install.install import InstallError
-from calculate.update.update import Update,UpdateError
+from calculate.update.update import Update, UpdateError
 from calculate.lib.utils.portage import GitError
 from utils.cl_update import ClUpdateAction
 from utils.cl_update_profile import ClUpdateProfileAction
 from utils.cl_setup_update import ClSetupUpdateAction
-from calculate.lib.cl_lang import setLocalTranslate,getLazyLocalTranslate
-setLocalTranslate('cl_update3',sys.modules[__name__])
+from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
+
+setLocalTranslate('cl_update3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 
